@@ -24,6 +24,7 @@ from ibm_watson_machine_learning.model_definition import ModelDefinition
 from ibm_watson_machine_learning.models import Models
 from ibm_watson_machine_learning.pipelines import Pipelines
 from ibm_watson_machine_learning.deployments import Deployments
+from ibm_watson_machine_learning.factsheets import Factsheets
 from ibm_watson_machine_learning.training import Training
 from ibm_watson_machine_learning.functions import Functions
 from ibm_watson_machine_learning.platform_spaces import PlatformSpaces
@@ -79,7 +80,6 @@ class APIClient:
         self.ICP_35 = False # Use it for any 3.5 specific functionalities
         self.ICP_40 = False # Use it for any 4.0 specific functionalities
         self.CLOUD_BETA_FLOW = False
-        # self.version_param = '2020-06-12'
 
         self.PLATFORM_URLS_MAP = {
             'https://wml-dev.ml.test.cloud.ibm.com': 'https://api.dataplatform.dev.cloud.ibm.com',
@@ -339,6 +339,7 @@ class APIClient:
             if self.CLOUD_PLATFORM_SPACES:
                 from ibm_watson_machine_learning.migration_v4ga_cloud import Migrationv4GACloud
                 self.v4ga_cloud_migration = Migrationv4GACloud(self)
+                self.factsheets = Factsheets(self)
 
             self.remote_training_systems = RemoteTrainingSystem(self)
 
