@@ -27,7 +27,8 @@ from ..experiment import AutoAI
 from ..utils.autoai.utils import (prepare_auto_ai_model_to_publish, prepare_auto_ai_model_to_publish_normal_scenario,
                                   remove_file, prepare_auto_ai_model_to_publish_notebook,
                                   prepare_auto_ai_model_to_publish_notebook_normal_scenario,
-                                  download_wml_pipeline_details_from_file, get_sw_spec_and_type_based_on_sklearn)
+                                  download_wml_pipeline_details_from_file, get_sw_spec_and_type_based_on_sklearn,
+                                  check_if_ts_pipeline_is_winner)
 from ..utils.deployment.errors import (WrongDeploymnetType, ModelTypeNotSupported, NotAutoAIExperiment,
                                        DeploymentNotSupported, MissingSpace, ModelPromotionFailed,
                                        ServingNameNotAvailable)
@@ -246,6 +247,8 @@ class BaseDeployment(ABC):
                     schema['schemas'] if self._obm else [schema])
 
             else:
+                # raise an error when TS pipeline is discarded one
+                check_if_ts_pipeline_is_winner(details=run_params, model_name=model)
 
                 # Note: We need to fetch credentials when 'container' is the type
                 if run_params['entity']['results_reference']['type'] == 'container':
