@@ -1409,7 +1409,7 @@ class Deployments(WMLResource):
                                  transaction_id=transaction_id,
                                  retention=retention)
 
-    def get_job_details(self, job_uid=None, limit=None):
+    def get_job_details(self, job_uid=None, include=None, limit=None):
         """
            Get information about your deployment job(s). If  deployment job_uid is not passed, all deployment jobs details are fetched.
 
@@ -1419,6 +1419,8 @@ class Deployments(WMLResource):
 
                 #. **job_uid**: Unique Job ID (optional)\n
                    **type**: str\n
+                #. **include**:  fields to be retrieved from 'decision_optimization' and 'scoring' section mentioned as value(s) (comma separated) as output response fields (optional)\n
+                   **type**: str\n
                 #. **limit**:  limit number of fetched records (optional)\n
                    **type**: int\n
 
@@ -1443,20 +1445,13 @@ class Deployments(WMLResource):
             Deployments._validate_type(job_uid, u'job_uid', STR_TYPE, True)
         url = self._client.service_instance._href_definitions.get_async_deployment_job_href()
 
-        if self._ICP:
-            if job_uid is not None:
-                url = url + '/' + job_uid
-                response = requests.get(
-                    url,
-                    headers=self._client._get_headers(),
-                    params=self._client._params(),
-                    verify=False
-                )
-                return self._handle_response(200, "async deployment job", response)
-            else:
-                return self._get_artifact_details(url, job_uid, limit, 'async deployment jobs')
-        else:
-            return self._get_artifact_details(url, job_uid, limit, 'async deployment jobs')
+        params = self._client._params()
+        if include:
+            params['include'] = include
+
+        return self._get_artifact_details(url, job_uid, limit,
+                                          'async deployment job' if job_uid else 'async deployment jobs',
+                                          query_params=params)
 
     def get_job_status(self, job_id):
         """
