@@ -293,6 +293,23 @@ class WMLEngine(BaseEngine):
                 'excel_sheet'] = self._auto_pipelines_parameters.get('excel_sheet')
         # --- end note
 
+        # note: Fill test data params if specified (not the standard ones)
+        if self._auto_pipelines_parameters.get('test_data_csv_separator') != ',':
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters'][
+                'test_input_file_separator'] = self._auto_pipelines_parameters.get('test_data_csv_separator')
+
+        if self._auto_pipelines_parameters.get('test_data_excel_sheet') != 0:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters'][
+                'test_excel_sheet'] = self._auto_pipelines_parameters.get('test_data_excel_sheet')
+
+        if self._auto_pipelines_parameters.get('test_data_encoding') != 'utf-8':
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters'][
+                'test_encoding'] = self._auto_pipelines_parameters.get('test_data_encoding')
+        # --- end note
+
         # note: KB part: send version autoai_pod_version if set in pipeline details details (See supported formats)
         if not self._wml_client.ICP and self._auto_pipelines_parameters['autoai_pod_version'] is not None:
             self._wml_pipeline_metadata[
@@ -367,12 +384,13 @@ class WMLEngine(BaseEngine):
             else:
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['engine'][
-                    'template_id'] = 'spark-3.0.0-automl-cp4d-template'
+                    'template_id'] = 'spark-3.0.0-automl-cp4d-template' if not (self._wml_client.ICP_30 or self._wml_client.ICP_35) else 'spark-2.4.0-automl-icp4d-template'
         # --- end note
 
     def _initialize_wml_training_metadata(self,
                                           training_data_reference: List['DataConnection'],
-                                          training_results_reference: 'DataConnection') -> None:
+                                          training_results_reference: 'DataConnection',
+                                          test_data_references: List['DataConnection'] = None) -> None:
         """
         Initialization of wml training metadata (WML client Meta Parameter).
 
@@ -384,6 +402,8 @@ class WMLEngine(BaseEngine):
         training_results_reference: DataConnection, required
             Data storage connection details to store pipeline training results.
 
+        test_data_references: List[DataConnection], optional
+            Data storage connection details to inform where test / holdout data is stored.
         """
         self._wml_training_metadata = {
             self._wml_client.training.ConfigurationMetaNames.TAGS:
@@ -407,6 +427,11 @@ class WMLEngine(BaseEngine):
                 f"wml pipeline: {self._wml_stored_pipeline_details['metadata']['id']}",
         }
 
+        if test_data_references is not None:
+            self._wml_training_metadata[
+                self._wml_client.training.ConfigurationMetaNames.TEST_DATA_REFERENCE
+            ] = [connection._to_dict() for connection in test_data_references]
+
         # note: Delete unnecessary keys for connection_asset in training_data_reference
         for connection in \
                 self._wml_training_metadata[self._wml_client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES] +\
@@ -457,7 +482,8 @@ class WMLEngine(BaseEngine):
     def fit(self,
             training_data_reference: List['DataConnection'],
             training_results_reference: 'DataConnection',
-            background_mode: bool = True) -> dict:
+            background_mode: bool = True,
+            test_data_references: List['DataConnection'] = None) -> dict:
         """
         Run a training process on WML of autoai on top of the training data referenced by training_data_connection.
 
@@ -472,12 +498,16 @@ class WMLEngine(BaseEngine):
         background_mode: bool, optional
             Indicator if fit() method will run in background (async) or (sync).
 
+        test_data_references: List[DataConnection], optional
+            Data storage connection details to inform where test / holdout data is stored.
+
         Returns
         -------
         Dictionary with run details.
         """
         self._initialize_wml_training_metadata(training_data_reference=training_data_reference,
-                                               training_results_reference=training_results_reference)
+                                               training_results_reference=training_results_reference,
+                                               test_data_references=test_data_references)
 
         run_params = self._wml_client.training.run(meta_props=self._wml_training_metadata,
                                                    asynchronous=True)
