@@ -12,9 +12,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import os
+
 from copy import deepcopy
 from typing import TYPE_CHECKING, List, Union
 from warnings import warn
+from contextlib import redirect_stdout
 
 from numpy import ndarray
 from pandas import DataFrame
@@ -699,7 +702,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         """
         user_holdout_exists = True
         try:
-            self.get_test_data_connections()
+            with redirect_stdout(open(os.devnull, "w")):
+                self.get_test_data_connections()
 
         except TestDataNotPresent:
             user_holdout_exists = False
