@@ -201,7 +201,7 @@ class Experiments(WMLResource):
 
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, experiment_uid=None, limit=None):
+    def get_details(self, experiment_uid=None, limit=None, asynchronous=False, get_all=False):
         """
                 Get metadata of experiment(s). If no experiment UID is specified all experiments metadata is returned.
 
@@ -213,6 +213,10 @@ class Experiments(WMLResource):
                           **type**: str\n
                        #. **limit**:  limit number of fetched records (optional)\n
                           **type**: int\n
+                       #. **asynchronous**:  if True, it will work as a generator (optional)\n
+                          **type**: bool\n
+                       #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+                          **type**: bool\n
 
                 **Output**
 
@@ -230,6 +234,11 @@ class Experiments(WMLResource):
 
                      >>> experiment_details = client.experiments.get_details(experiment_uid)
                      >>> experiment_details = client.experiments.get_details()
+                     >>> experiment_details = client.experiments.get_details(limit=100)
+                     >>> experiment_details = client.experiments.get_details(limit=100, get_all=True)
+                     >>> experiment_details = []
+                     >>> for entry in client.experiments.get_details(limit=100, asynchronous=True, get_all=True):
+                     >>>    experiment_details.extend(entry)
 
          """
         ##For CP4D, check if either spce or project ID is set
@@ -237,7 +246,12 @@ class Experiments(WMLResource):
         experiment_uid = str_type_conv(experiment_uid)
         url = self._client.service_instance._href_definitions.get_experiments_href()
 
-        return self._get_artifact_details(url, experiment_uid, limit, 'experiment')
+        if experiment_uid is None:
+            return self._get_artifact_details(url, experiment_uid, limit, 'experiment',
+                                              _async=asynchronous, _all=get_all)
+
+        else:
+            return self._get_artifact_details(url, experiment_uid, limit, 'experiment')
 
     @staticmethod
     @docstring_parameter({'str_type': STR_TYPE_NAME})
