@@ -286,7 +286,7 @@ class Export(WMLResource):
             print("Export job deleted")
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, export_id=None, space_id=None, project_id=None, limit=None):
+    def get_details(self, export_id=None, space_id=None, project_id=None, limit=None, asynchronous=False, get_all=False):
         """
             Get metadata of the given export job. if no export_id is specified all
             exports metadata is returned.
@@ -302,6 +302,10 @@ class Export(WMLResource):
                    **type**: str\n
                 #. **limit**:  limit number of fetched records (optional)\n
                    **type**: int\n
+                #. **asynchronous**:  if True, it will work as a generator (optional)\n
+                   **type**: bool\n
+                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+                   **type**: bool\n
 
            **Output**
 
@@ -317,6 +321,11 @@ class Export(WMLResource):
 
              >>> details = client.export_assets.get_details(export_id, space_id= '98a53931-a8c0-4c2f-8319-c793155e4598')
              >>> details = client.export_assets.get_details()
+             >>> details = client.export_assets.get_details(limit=100)
+             >>> details = client.export_assets.get_details(limit=100, get_all=True)
+             >>> details = []
+             >>> for entry in client.export_assets.get_details(limit=100, asynchronous=True, get_all=True):
+             >>>    details.extend(entry)
          """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
@@ -339,7 +348,12 @@ class Export(WMLResource):
         else:
             params.update({"project_id": project_id})
 
-        return self._get_artifact_details(href, export_id, limit, 'export job', query_params=params)
+        if export_id is None:
+            return self._get_artifact_details(href, export_id, limit, 'export job', query_params=params,
+                                              _async=asynchronous, _all=get_all)
+
+        else:
+            return self._get_artifact_details(href, export_id, limit, 'export job', query_params=params)
     
     def list(self, space_id=None, project_id=None, limit=None):
         """
