@@ -658,7 +658,7 @@ class BaseDataConnection(ABC):
         # Note: workaround with volumes API as connections API changes data format
         connection_details = self._wml_client.connections.get_details(connection_id)
 
-        href = self._wml_client.volumes._href_definitions.volume_upload_href(
+        href = self._wml_client.volumes._client.service_instance._href_definitions.volume_upload_href(
             connection_details['entity']['properties']['volume'])
         full_href = f"{href[:-1]}{connection_path}"
 
