@@ -547,7 +547,8 @@ class ModelCollection:
         asyncValue = "false"
         if query_param is not None:
             for key in query_param:
-                if (key != 'async' and key != 'space_id' and key != 'project_id'  and key != 'version' and key != 'content_format'):
+                if (key != 'async' and key != 'space_id' and key != 'project_id'  and key != 'version' and
+                        key != 'content_format' and key != 'userfs'):
                     raise ValueError("Got an unexpected keyword argument '%s'" % key)
                 else:
                     if (key == 'async'):
