@@ -260,7 +260,7 @@ class Migrationv4GACloud(WMLResource):
             print("Migration job deleted")
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, migration_id=None, space_id=None, project_id=None, limit=None):
+    def get_details(self, migration_id=None, space_id=None, project_id=None, limit=None, asynchronous=False, get_all=False):
         """
         Get metadata of of the migration job function(s). If no migration_id is specified all migration jobs
         metadata is returned.
@@ -276,6 +276,10 @@ class Migrationv4GACloud(WMLResource):
                 **type**: str\n
             #. **limit**:  limit number of fetched records (optional)\n
                 **type**: int\n
+            #. **asynchronous**:  if True, it will work as a generator (optional)\n
+               **type**: bool\n
+            #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+               **type**: bool\n
 
         **Output**
 
@@ -288,6 +292,11 @@ class Migrationv4GACloud(WMLResource):
 
          >>> migration_details = client.v4ga_cloud_migration.get_details(migration_id='6213cf1-252f-424b-b52d-5cdd9814956c',
          >>>                                                             space_id='3421cf1-252f-424b-b52d-5cdd981495fe')
+         >>> migration_details = client.v4ga_cloud_migration.get_details(limit=100)
+         >>> migration_details = client.v4ga_cloud_migration.get_details(limit=100, get_all=True)
+         >>> migration_details = []
+         >>> for entry in client.v4ga_cloud_migration.get_details(limit=100, asynchronous=True, get_all=True):
+         >>>    migration_details.extend(entry)
         """
 
         if self.skip_msg is False:
@@ -307,7 +316,12 @@ class Migrationv4GACloud(WMLResource):
 
         href = self._client.service_instance._href_definitions.v4ga_cloud_migration_href()
 
-        return self._get_artifact_details(href, migration_id, limit, 'migration', query_params=query_params)
+        if migration_id is None:
+            return self._get_artifact_details(href, migration_id, limit, 'migration', query_params=query_params,
+                                              _async=asynchronous, _all=get_all)
+
+        else:
+            return self._get_artifact_details(href, migration_id, limit, 'migration', query_params=query_params)
 
     def list(self, space_id=None, project_id=None, limit=None):
         """
