@@ -4,3 +4,5 @@ from .abstract_deployment_batch import AbstractTestBatch
 from .abstract_test_iris_wml_autoai_multiclass_connections import AbstractTestAutoAIRemote
 from .abstract_test_iris_using_database_connection import AbstractTestAutoAIDatabaseConnection
 from .abstract_test_iris_using_database_data_asset import AbstractTestAutoAIConnectedAsset
+from .abstract_obm_autoai_test import AbstractTestOBM
+from .abstract_timeseries_test import AbstractTestTSAsync
