@@ -45,6 +45,7 @@ class AbstractTestBatch(abc.ABC):
 
     asset_id: str
     batch_payload_location: str
+    batch_payload_cos_location: str
     batch_output_filename = f"batch_output_{datetime.utcnow().isoformat()}.csv"
 
     space_id: str
@@ -182,6 +183,16 @@ class AbstractTestBatch(abc.ABC):
         results_reference = DataConnection(
             location=DeploymentOutputAssetLocation(name=test_case_batch_output_filename))
 
+        AbstractTestBatch.bucket_name = save_data_to_cos_bucket(self.batch_payload_location,
+                                                                self.batch_payload_cos_location,
+                                                                access_key_id=self.cos_credentials['cos_hmac_keys'][
+                                                                    'access_key_id'],
+                                                                secret_access_key=
+                                                                self.cos_credentials['cos_hmac_keys'][
+                                                                    'secret_access_key'],
+                                                                cos_endpoint=self.cos_endpoint,
+                                                                bucket_name=self.bucket_name)
+
         # prepare connection
         connection_details = self.wml_client.connections.create({
             'datasource_type': self.wml_client.connections.get_datasource_type_uid_by_name(
@@ -201,20 +212,11 @@ class AbstractTestBatch(abc.ABC):
         self.assertIsNotNone(self.batch_payload_location,
                              "Test configuration failure: Batch payload location is missing")
 
-        AbstractTestBatch.bucket_name = save_data_to_cos_bucket(self.batch_payload_location,
-                                                                self.batch_payload_cos_location,
-                                                                access_key_id=self.cos_credentials['cos_hmac_keys'][
-                                                                    'access_key_id'],
-                                                                secret_access_key=
-                                                                self.cos_credentials['cos_hmac_keys'][
-                                                                    'secret_access_key'],
-                                                                cos_endpoint=self.cos_endpoint,
-                                                                bucket_name=self.bucket_name)
 
         asset_details = self.wml_client.data_assets.store({
             self.wml_client.data_assets.ConfigurationMetaNames.CONNECTION_ID: AbstractTestBatch.connection_id,
             self.wml_client.data_assets.ConfigurationMetaNames.NAME: "Batch deployment asset",
-            self.wml_client.data_assets.ConfigurationMetaNames.DATA_CONTENT_NAME: self.batch_payload_cos_location
+            self.wml_client.data_assets.ConfigurationMetaNames.DATA_CONTENT_NAME: f"{self.bucket_name}/{self.batch_payload_cos_location}"
         })
 
         asset_id = self.wml_client.data_assets.get_id(asset_details)
@@ -294,7 +296,7 @@ class AbstractTestBatch(abc.ABC):
             connection_asset_id=AbstractTestBatch.connection_id,
             location=S3Location(
                 bucket=self.bucket_name,
-                path=self.data_cos_path
+                path=self.batch_payload_cos_location
             )
         )
 
