@@ -56,7 +56,8 @@ class AbstractTestOBM(abc.ABC):
 
     BATCH_DEPLOYMENT_WITH_DA = True  # batch input passed as DataConnection type data-assets with csv files
     BATCH_DEPLOYMENT_WITH_CDA = True  # batch input passed as DataConnection type data-assets with connection_id(COS)
-    BATCH_DEPLOYMENT_WITH_CA = True  # batch input passed as DataConnection type connected assets (COS)
+    BATCH_DEPLOYMENT_WITH_CA_DA = True  # batch input passed as DataConnection type connected assets (COS) output is data asset csv file
+    BATCH_DEPLOYMENT_WITH_CA_CA = True # batch input and output passed as DataConnection type connected assets (COS)
 
     DEPLOYMENT_NAME = "SDK tests Deployment"
 
@@ -112,7 +113,7 @@ class AbstractTestOBM(abc.ABC):
     asset_id = None
     connection_id = None
 
-    data_assets_to_delete: list = []
+    data_assets_to_delete: set = set()
 
     @classmethod
     def setUpClass(cls) -> None:
@@ -194,8 +195,9 @@ class AbstractTestOBM(abc.ABC):
 
         AbstractTestOBM.remote_auto_pipelines = self.experiment.optimizer(**AbstractTestOBM.experiment_info)
 
-        self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
-                              msg="experiment.optimizer did not return RemoteAutoPipelines object")
+        self.assertIsInstance(AbstractTestOBM.remote_auto_pipelines, RemoteAutoPipelines,
+                              msg=f"experiment.optimizer did not return RemoteAutoPipelines object, "
+                                  f"type: {type(AbstractTestOBM.remote_auto_pipelines)}")
 
     def test_06_get_configuration_parameters_of_remote_auto_pipeline(self):
         print("Getting experiment configuration parameters...")
@@ -263,6 +265,7 @@ class AbstractTestOBM(abc.ABC):
     def test_12_get_metrics(self):
         metrics = self.wml_client.training.get_metrics(self.run_id)
         self.assertIsNotNone(metrics)
+        self.assertGreater(len(metrics), 0)
 
     def test_13_visualize_obm_pipeline(self):
         print("Visualizing OBM model ...")
@@ -488,7 +491,7 @@ class AbstractTestOBM(abc.ABC):
                 name=data_filename,
                 file_path=self.input_data_path + data_filename)
             asset_id = asset_details['metadata']['guid']
-            AbstractTestOBM.data_assets_to_delete.append(asset_id)
+            AbstractTestOBM.data_assets_to_delete.add(asset_id)
 
             conn_space = DataConnection(
                 data_join_node_name=node_name,
@@ -530,22 +533,6 @@ class AbstractTestOBM(abc.ABC):
             location=DeploymentOutputAssetLocation(name=test_case_batch_output_filename))
 
         # prepare connection
-        if not self.connection_id:
-            connection_details = self.wml_client.connections.create({
-                'datasource_type': self.wml_client.connections.get_datasource_type_uid_by_name(
-                    'bluemixcloudobjectstorage'),
-                'name': 'Connection to COS for tests',
-                'properties': {
-                    'bucket': self.bucket_name,
-                    'access_key': self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                    'secret_key': self.cos_credentials['cos_hmac_keys']['secret_access_key'],
-                    'iam_url': self.wml_client.service_instance._href_definitions.get_iam_token_url(),
-                    'url': self.cos_endpoint
-                }
-            })
-
-            self.connection_id = self.wml_client.connections.get_uid(connection_details)
-
         AbstractTestOBM.bucket_name = save_data_to_cos_bucket(self.input_data_path,
                                                               data_filenames=self.input_data_filenames,
                                                               data_cos_path=self.data_cos_path,
@@ -558,21 +545,36 @@ class AbstractTestOBM(abc.ABC):
                                                               cos_endpoint=self.cos_endpoint,
                                                               bucket_name=self.bucket_name)
 
+        connection_details = self.wml_client.connections.create({
+            'datasource_type': self.wml_client.connections.get_datasource_type_uid_by_name(
+                'bluemixcloudobjectstorage'),
+            'name': 'Connection to COS for tests',
+            'properties': {
+                'bucket': self.bucket_name,
+                'access_key': self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                'secret_key': self.cos_credentials['cos_hmac_keys']['secret_access_key'],
+                'iam_url': self.wml_client.service_instance._href_definitions.get_iam_token_url(),
+                'url': self.cos_endpoint
+            }
+        })
+
+        AbstractTestOBM.connection_id = self.wml_client.connections.get_uid(connection_details)
+
         # create connected data asset for each data set
 
         data_connections_space_only = []
 
         for node_name, data_filename in zip(self.input_node_names, self.input_data_filenames):
             asset_details = self.wml_client.data_assets.store({
-                self.wml_client.data_assets.ConfigurationMetaNames.CONNECTION_ID: self.connection_id,
+                self.wml_client.data_assets.ConfigurationMetaNames.CONNECTION_ID: AbstractTestOBM.connection_id,
                 self.wml_client.data_assets.ConfigurationMetaNames.NAME: f"Batch deployment asset - {node_name}",
                 self.wml_client.data_assets.ConfigurationMetaNames.DATA_CONTENT_NAME: os.path.join(
-                    self.data_cos_path, data_filename)
+                    self.bucket_name, self.data_cos_path, data_filename)
             })
 
             asset_id = self.wml_client.data_assets.get_id(asset_details)
 
-            AbstractTestOBM.data_assets_to_delete.append(asset_id)
+            AbstractTestOBM.data_assets_to_delete.add(asset_id)
 
             self.assertIsInstance(asset_id, str)
 
@@ -600,20 +602,29 @@ class AbstractTestOBM(abc.ABC):
 
         self.assertIsNotNone(predictions)
 
-    def test_47_run_job_batch_deployed_model_with_connected_data_asset(self):
+    def test_47a_run_job_batch_deployed_model_with_connected_asset_out_connected_asset(self):
 
-        if not self.BATCH_DEPLOYMENT_WITH_CA:
+        if not self.BATCH_DEPLOYMENT_WITH_CA_CA:
             self.skipTest("Skip batch deployment run job with connected asset with cos connection type")
         data_connections_space_only = []
         self.wml_client.set.default_space(AbstractTestOBM.target_space_id)
 
-        test_case_batch_output_filename = "cos_ca_" + self.batch_output_filename
+        test_case_batch_output_filename = "cos_ca_ca" + self.batch_output_filename
 
-        results_reference = DataConnection(
-            location=DeploymentOutputAssetLocation(name=test_case_batch_output_filename))
+        AbstractTestOBM.bucket_name = save_data_to_cos_bucket(self.input_data_path,
+                                                              data_filenames=self.input_data_filenames,
+                                                              data_cos_path=self.data_cos_path,
+                                                              access_key_id=
+                                                              self.cos_credentials['cos_hmac_keys'][
+                                                                  'access_key_id'],
+                                                              secret_access_key=
+                                                              self.cos_credentials['cos_hmac_keys'][
+                                                                  'secret_access_key'],
+                                                              cos_endpoint=self.cos_endpoint,
+                                                              bucket_name=self.bucket_name)
 
         # prepare connection
-        if not self.connection_id:
+        if not AbstractTestOBM.connection_id:
             connection_details = self.wml_client.connections.create({
                 'datasource_type': self.wml_client.connections.get_datasource_type_uid_by_name(
                     'bluemixcloudobjectstorage'),
@@ -627,15 +638,90 @@ class AbstractTestOBM(abc.ABC):
                 }
             })
 
-            self.connection_id = self.wml_client.connections.get_uid(connection_details)
+            AbstractTestOBM.connection_id = self.wml_client.connections.get_uid(connection_details)
 
         for node_name, data_filename in zip(self.input_node_names, self.input_data_filenames):
             conn_space = DataConnection(
                 data_join_node_name=node_name,
-                connection_asset_id=self.connection_id,
+                connection_asset_id=AbstractTestOBM.connection_id,
                 location=S3Location(
                     bucket=self.bucket_name,
-                    path=self.data_cos_path
+                    path=os.path.join(self.data_cos_path, data_filename)
+                )
+            )
+
+            data_connections_space_only.append(conn_space)
+
+        results_reference = DataConnection(
+                connection_asset_id=AbstractTestOBM.connection_id,
+                location=S3Location(
+                    bucket=self.bucket_name,
+                    path=test_case_batch_output_filename
+                )
+            )
+
+        scoring_params = AbstractTestOBM.service_batch.run_job(
+            payload=data_connections_space_only,
+            output_data_reference=results_reference,
+            background_mode=False)
+
+        print(scoring_params)
+        self.assertIsNotNone(scoring_params)
+
+        deployment_job_id = self.wml_client.deployments.get_job_uid(scoring_params)
+
+        predictions = AbstractTestOBM.service_batch.get_job_result(deployment_job_id)
+        print(predictions)
+        self.assertIsNotNone(predictions)
+        
+    def test_47b_run_job_batch_deployed_model_with_connected_asset_out_data_asset(self):
+
+        if not self.BATCH_DEPLOYMENT_WITH_CA_DA:
+            self.skipTest("Skip batch deployment run job with connected asset with cos connection type")
+        data_connections_space_only = []
+        self.wml_client.set.default_space(AbstractTestOBM.target_space_id)
+
+        test_case_batch_output_filename = "cos_ca_" + self.batch_output_filename
+
+        AbstractTestOBM.bucket_name = save_data_to_cos_bucket(self.input_data_path,
+                                                              data_filenames=self.input_data_filenames,
+                                                              data_cos_path=self.data_cos_path,
+                                                              access_key_id=
+                                                              self.cos_credentials['cos_hmac_keys'][
+                                                                  'access_key_id'],
+                                                              secret_access_key=
+                                                              self.cos_credentials['cos_hmac_keys'][
+                                                                  'secret_access_key'],
+                                                              cos_endpoint=self.cos_endpoint,
+                                                              bucket_name=self.bucket_name)
+
+        results_reference = DataConnection(
+            location=DeploymentOutputAssetLocation(name=test_case_batch_output_filename))
+
+        # prepare connection
+        if not AbstractTestOBM.connection_id:
+            connection_details = self.wml_client.connections.create({
+                'datasource_type': self.wml_client.connections.get_datasource_type_uid_by_name(
+                    'bluemixcloudobjectstorage'),
+                'name': 'Connection to COS for tests',
+                'properties': {
+                    'bucket': self.bucket_name,
+                    'access_key': self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    'secret_key': self.cos_credentials['cos_hmac_keys']['secret_access_key'],
+                    'iam_url': self.wml_client.service_instance._href_definitions.get_iam_token_url(),
+                    'url': self.cos_endpoint
+                }
+            })
+
+            AbstractTestOBM.connection_id = self.wml_client.connections.get_uid(connection_details)
+
+        for node_name, data_filename in zip(self.input_node_names, self.input_data_filenames):
+            conn_space = DataConnection(
+                data_join_node_name=node_name,
+                connection_asset_id=AbstractTestOBM.connection_id,
+                location=S3Location(
+                    bucket=self.bucket_name,
+                    path=os.path.join(self.data_cos_path, data_filename)
                 )
             )
 
@@ -674,11 +760,14 @@ class AbstractTestOBM(abc.ABC):
         self.wml_client.set.default_space(self.target_space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(AbstractTestOBM.service_batch.asset_id)
 
-        print(f"Delete all created assets in Batch deployment tests. {AbstractTestOBM.data_assets_to_delete}")
-        for asset_id in AbstractTestOBM.data_assets_to_delete:
-            self.wml_client.data_assets.delete(asset_id)
-
         self.assertEqual(AbstractTestOBM.service_batch.id, None, msg="Deployment ID deleted incorrectly")
         self.assertEqual(AbstractTestOBM.service_batch.name, None, msg="Deployment name deleted incorrectly")
         self.assertEqual(AbstractTestOBM.service_batch.scoring_url, None,
                          msg="Deployment scoring_url deleted incorrectly")
+
+        print(f"Delete all created assets in Batch deployment tests. {AbstractTestOBM.data_assets_to_delete}")
+        for asset_id in AbstractTestOBM.data_assets_to_delete:
+            self.wml_client.data_assets.delete(asset_id)
+
+        print(f"Delete connection used in Batch deployment tests. {AbstractTestOBM.connection_id}")
+        self.wml_client.connections.delete(AbstractTestOBM.connection_id)
\ No newline at end of file
