@@ -37,8 +37,10 @@ class AbstractTestAutoAIRemote(abc.ABC):
     service: 'WebService' = None
     service_batch: 'Batch' = None
 
-    data_location = './autoai/data/iris_dataset.csv'
-    custom_separator = ','
+    data_location = './autoai/data/xlsx/iris_dataset.xlsx'
+    # custom_separator = ','
+
+    sheet_name = "iris"
 
     prediction_column = 'species'
 
@@ -55,7 +57,7 @@ class AbstractTestAutoAIRemote(abc.ABC):
     space_name = environ.get('SPACE_NAME', 'regression_tests_sdk_space')
 
     cos_endpoint = "https://s3.us-south.cloud-object-storage.appdomain.cloud"
-    data_cos_path = 'iris_dataset.csv'
+    data_cos_path = 'iris_dataset.xlsx'
     cos_resource_instance_id = None
 
     results_cos_path = 'results_wml_autoai'
@@ -118,15 +120,16 @@ class AbstractTestAutoAIRemote(abc.ABC):
             name=self.OPTIMIZER_NAME,
             desc='test description',
             prediction_type=self.experiment.PredictionType.MULTICLASS,
-            prediction_column='species',
+            prediction_column=self.prediction_column,
             holdout_size=0.15,
             max_number_of_estimators=1,
-            csv_separator=self.custom_separator,
+            # csv_separator=self.custom_separator,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
             autoai_pod_version=self.pod_version,
             notebooks=True,
             n_parallel_data_connections=self.max_connection_nb,
-            retrain_on_holdout=True
+            retrain_on_holdout=True,
+            excel_sheet=self.sheet_name
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -158,16 +161,25 @@ class AbstractTestAutoAIRemote(abc.ABC):
         AbstractTestAutoAIRemote.y_values = self.train_data[self.prediction_column][:10]
 
     def test_06b_get_train_data(self):
-        train_data, holdout_data = self.remote_auto_pipelines.get_data_connections()[0].read(with_holdout_split=True)
+        X_train, X_holdout, y_train, y_holdout = self.remote_auto_pipelines.get_data_connections()[0].read(with_holdout_split=True)
 
         print("train data sample:")
-        print(train_data)
+        print(X_train)
+        print(y_train)
         print("holdout data sample:")
-        print(holdout_data)
+        print(X_holdout)
+        print(y_holdout)
+
+        self.assertGreater(len(X_train), 0)
+        self.assertGreater(len(X_holdout), 0)
+        self.assertEqual(len(X_train), len(y_train))
+        self.assertEqual(len(X_holdout), len(y_holdout))
 
     def test_07_get_run_status(self):
         status = self.remote_auto_pipelines.get_run_status()
-        self.assertEqual(status, "completed", msg="AutoAI run didn't finished successfully. Status: {}".format(status))
+        self.assertEqual(status, "completed", msg="AutoAI run didn't finished successfully. "
+                                                  "Status: {}\n run details: {}".format(status,
+                                                                                        self.remote_auto_pipelines.get_run_details()))
 
     def test_08_get_run_details(self):
         parameters = self.remote_auto_pipelines.get_run_details()
@@ -180,7 +192,7 @@ class AbstractTestAutoAIRemote(abc.ABC):
         self.wml_client.training.get_metrics(self.run_id)
 
     def test_09_predict_using_fitted_pipeline(self):
-        predictions = self.remote_auto_pipelines.predict(X=self.train_data.drop(['species'], axis=1).values[:5])
+        predictions = self.remote_auto_pipelines.predict(X=self.X_values[:5])
         print(predictions)
         self.assertGreater(len(predictions), 0)
 
@@ -280,7 +292,6 @@ class AbstractTestAutoAIRemote(abc.ABC):
         print(predictions)
         self.assertGreater(len(predictions), 0, msg="Empty predictions")
 
-
     #################################
     #      DEPLOYMENT SECTION       #
     #################################
@@ -314,7 +325,7 @@ class AbstractTestAutoAIRemote(abc.ABC):
 
     def test_21_score_deployed_model(self):
         nb_records = 5
-        predictions = self.service.score(payload=self.train_data.drop(['species'], axis=1)[:nb_records])
+        predictions = self.service.score(payload=self.train_data.drop([self.prediction_column], axis=1)[:nb_records])
         print(predictions)
         self.assertIsNotNone(predictions)
         self.assertEqual(len(predictions['predictions'][0]['values']), nb_records)
@@ -364,7 +375,7 @@ class AbstractTestAutoAIRemote(abc.ABC):
 
     def test_26_score_batch_deployed_model(self):
         scoring_params = self.service_batch.run_job(
-            payload=self.train_data.drop(columns=['species']),
+            payload=self.train_data.drop(columns=[self.prediction_column]),
             background_mode=False)
         print(scoring_params)
         print(self.service_batch.get_job_result(scoring_params['metadata']['id']))
