@@ -21,7 +21,11 @@ class TestAutoAIRemote(AbstractTestTSAsync, unittest.TestCase):
 
     data_cos_path = 'Twitter_volume_AMZN.csv'
 
+    batch_payload_location = data_location
+    batch_payload_cos_location = data_cos_path
+
     SPACE_ONLY = False
+    BATCH_DEPLOYMENT = False
 
     OPTIMIZER_NAME = "Twitter_volume_AMZN test sdk"
     DEPLOYMENT_NAME = OPTIMIZER_NAME + "Deployment"
