@@ -20,8 +20,8 @@ class TestAutoAIRemote(AbstractTestAutoAIAsync, AbstractTestWebservice, Abstract
 
     data_cos_path = 'data/credit_risk_training_500.csv'
 
-    batch_payload_location = data_location
-    batch_payload_cos_location = data_cos_path
+    batch_payload_location ='./autoai/data/credit_risk_scoring_payload.csv'
+    batch_payload_cos_location = 'scoring_payload/credit_risk_scoring_payload.csv'
 
     SPACE_ONLY = False
 
