@@ -30,7 +30,7 @@ from lale.operators import TrainablePipeline
 from ibm_watson_machine_learning.helpers import pipeline_to_script
 
 
-@unittest.skip( "Fairness metric is not supported ")
+@unittest.skip( "Fairness & S3 metric is not supported ")
 class TestAutoAIRemote(unittest.TestCase):
     """
     The test covers:
@@ -85,8 +85,8 @@ class TestAutoAIRemote(unittest.TestCase):
 
     fairness_info = {
         "protected_attributes": [
-            {"feature": "sex", "privileged_groups": ['male']},
-            {"feature": "age", "privileged_groups": [[20, 40], [60, 90]]}
+            {"feature": "sex", "reference_group": ['male']},
+            {"feature": "age", "reference_group": [[20, 40], [60, 90]]}
         ],
         "favorable_labels": [[1000.0, 5000.0]]}
 
