@@ -4,7 +4,7 @@ import ibm_boto3
 
 from ibm_watson_machine_learning.helpers.connections import DataConnection, ContainerLocation, S3Location
 from ibm_watson_machine_learning.utils.autoai.errors import WMLClientError
-from ibm_watson_machine_learning.tests.utils import bucket_exists, is_cp4d, create_bucket
+from ibm_watson_machine_learning.tests.utils import bucket_exists, is_cp4d, save_data_to_container
 from ibm_watson_machine_learning.tests.autoai.abstract_tests_classes import (
     AbstractTestAutoAIRemote)
 
@@ -25,6 +25,11 @@ class TestAutoAIRemote(AbstractTestAutoAIRemote, unittest.TestCase):
      - output: ConnectedDataAsset pointing to COS.
     """
 
+    def test_00d_write_data_to_container(self):
+        # writing to project
+        self.wml_client.set.default_project(self.project_id)
+        save_data_to_container(self.data_location, self.data_cos_path, self.wml_client)
+
     def test_02_DataConnection_setup(self):
         TestAutoAIRemote.data_connection = DataConnection(
             location=ContainerLocation(path=self.data_cos_path
