@@ -9,7 +9,7 @@ from ibm_watson_machine_learning.tests.autoai.abstract_tests_classes import (
     AbstractTestAutoAIRemote)
 
 
-@unittest.skipIf(is_cp4d(), "Supported only on CLOUD")
+@unittest.skip("S3 type no longer supported")
 class TestAutoAIRemote(AbstractTestAutoAIRemote, unittest.TestCase):
     """
     The test can be run on CLOUD
