@@ -11,7 +11,8 @@ from ibm_watson_machine_learning.experiment import AutoAI
 from ibm_watson_machine_learning.deployment import WebService, Batch
 from ibm_watson_machine_learning.workspace import WorkSpace
 
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, FSLocation, AssetLocation
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, FSLocation, \
+    AssetLocation
 
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
@@ -22,11 +23,10 @@ from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delet
 from ibm_watson_machine_learning.utils.autoai.enums import TShirtSize, PipelineTypes
 from ibm_watson_machine_learning.utils.autoai.errors import CannotReadSavedRemoteDataBeforeFit
 
-
 from lale.operators import TrainablePipeline
 
 
-# @unittest.skip('not supported yet')
+@unittest.skip("S3 type no longer supported")
 class TestAutoAIRemote(unittest.TestCase):
     """
     The test can be run on CLOUD, WMLS and CPD
@@ -48,7 +48,6 @@ class TestAutoAIRemote(unittest.TestCase):
     service: 'WebService' = None
     service_batch: 'Batch' = None
 
-
     trained_pipeline_details = None
     run_id = None
 
@@ -91,7 +90,6 @@ class TestAutoAIRemote(unittest.TestCase):
     project_id = None
     space_id = None
 
-
     @classmethod
     def setUpClass(cls) -> None:
         """
@@ -159,7 +157,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
             TestAutoAIRemote.results_connection = None
 
-        else: #for cloud and COS
+        else:  # for cloud and COS
             TestAutoAIRemote.data_connection = DataConnection(
                 connection=S3Connection(endpoint_url=self.cos_endpoint,
                                         access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
@@ -201,8 +199,7 @@ class TestAutoAIRemote(unittest.TestCase):
             holdout_size=0.1,
             autoai_pod_version=self.pod_version,
             t_shirt_size=TShirtSize.L,
-            # train_sample_columns_index_list = [1,2,3,5],
-            # text_columns_names=self.text_columns
+            text_columns_names=self.text_columns
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -251,7 +248,8 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(parameters)
 
     def test_08a_get_feature_importance(self):
-        feature_importance_df = self.remote_auto_pipelines.get_pipeline_details(pipeline_name='Pipeline_1').get('features_importance')
+        feature_importance_df = self.remote_auto_pipelines.get_pipeline_details(pipeline_name='Pipeline_1').get(
+            'features_importance')
         self.assertIsNotNone(feature_importance_df)
         str_feature_importance_index_list = str(list(feature_importance_df.sort_index().index))
 
@@ -261,7 +259,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
         self.assertIn('NewTextFeature_0', str_feature_importance_index_list,
                       msg="Text features were numerated incorrectly.")
-        self.assertIn(f'NewTextFeature_{self.word2vec_feature_number*len(self.text_columns)-1}',
+        self.assertIn(f'NewTextFeature_{self.word2vec_feature_number * len(self.text_columns) - 1}',
                       str_feature_importance_index_list, msg="Text features were numerated incorrectly.")
 
     def test_08b_get_metrics(self):
@@ -354,6 +352,7 @@ class TestAutoAIRemote(unittest.TestCase):
         except Exception as exception:
             self.assertIsNone(exception,
                               msg=f"Pretty print from lale pipeline was not successful \n\n Full pipeline code:\n {pipeline_code}")
+
     #################################
     #      DEPLOYMENT SECTION       #
     #################################
@@ -361,12 +360,12 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_21_deployment_setup_and_preparation(self):
         if self.wml_client.ICP:
             TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
-                                              source_project_id=self.project_id,
-                                              target_wml_credentials=self.wml_credentials,
-                                              target_space_id=self.space_id)
+                                                  source_project_id=self.project_id,
+                                                  target_wml_credentials=self.wml_credentials,
+                                                  target_space_id=self.space_id)
         else:
             TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
-                                                 source_space_id=self.space_id)
+                                                  source_space_id=self.space_id)
         self.wml_client.set.default_space(self.space_id)
         delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
         self.wml_client.set.default_project(self.project_id) if self.project_id else None
@@ -439,7 +438,7 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - missing id")
         self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - name not set")
         self.assertIsNotNone(self.service_batch.asset_id,
-                          msg="Batch Deployment creation - model (asset) id missing, incorrect model storing")
+                             msg="Batch Deployment creation - model (asset) id missing, incorrect model storing")
 
     def test_33_score_batch_deployed_model(self):
         scoring_params = self.service_batch.run_job(
