@@ -15,7 +15,8 @@ from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Loca
 
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
-from ibm_watson_machine_learning.utils.autoai.errors import NotExistingCOSResource, ForecastingUnsupportedOperation
+from ibm_watson_machine_learning.utils.autoai.errors import NotExistingCOSResource, ForecastingUnsupportedOperation, \
+    WrongModelName, DiscardedModel
 
 from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, bucket_exists,
                                                      create_bucket, get_space_id, is_cp4d)
@@ -67,6 +68,8 @@ class TestAutoAIRemote(unittest.TestCase):
     results_cos_path = 'results_wml_autoai'
 
     pipeline: 'Pipeline' = None
+    winning_pipelines_summary = None
+    discarded_pipelines_summary = None
     lale_pipeline = None
     deployed_pipeline = None
     hyperopt_pipelines = None
@@ -98,20 +101,18 @@ class TestAutoAIRemote(unittest.TestCase):
 
         cls.project_id = cls.wml_credentials.get('project_id')
 
-
     def test_00a_space_cleanup(self):
         space_cleanup(self.wml_client,
                       get_space_id(self.wml_client, self.space_name,
                                    cos_resource_instance_id=self.cos_resource_instance_id),
                       days_old=7)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
-                                     cos_resource_instance_id=self.cos_resource_instance_id)
+                                                 cos_resource_instance_id=self.cos_resource_instance_id)
         if self.wml_client.ICP:
             self.wml_client.set.default_project(self.project_id)
         else:
             self.wml_client.set.default_space(self.space_id)
 
-
     def test_00b_prepare_COS_instance(self):
         if self.wml_client.ICP:
             self.skipTest("Prepare COS is available only for Cloud")
@@ -140,10 +141,10 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_02_save_remote_data_and_DataConnection_setup(self):
         if self.wml_client.ICP:
             TestAutoAIRemote.data_connection = DataConnection(
-                            location=FSLocation(path=self.data_location))
+                location=FSLocation(path=self.data_location))
             TestAutoAIRemote.results_connection = None
 
-        else: #for cloud and COS
+        else:  # for cloud and COS
             TestAutoAIRemote.data_connection = DataConnection(
                 connection=S3Connection(endpoint_url=self.cos_endpoint,
                                         access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
@@ -183,7 +184,7 @@ class TestAutoAIRemote(unittest.TestCase):
             include_only_estimators=[AutoAI.ForecastingAlgorithms.ENSEMBLER],
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
             autoai_pod_version=self.pod_version,
-            #csv_separator=','
+            # csv_separator=','
 
         )
 
@@ -210,20 +211,23 @@ class TestAutoAIRemote(unittest.TestCase):
         if self.wml_client.ICP:
             self.skipTest("Prepare COS is available only for Cloud")
 
-        with self.assertRaises(NotExistingCOSResource, msg="Training should raise error when non existing COS bucket given"):
+        with self.assertRaises(NotExistingCOSResource,
+                               msg="Training should raise error when non existing COS bucket given"):
             self.remote_auto_pipelines.fit(
                 training_data_reference=[
                     DataConnection(
-                    connection=S3Connection(endpoint_url=self.cos_endpoint,
-                                            access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                                            secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-                    location=S3Location(bucket="not_existing",
-                                        path=self.data_cos_path)
-                )],
+                        connection=S3Connection(endpoint_url=self.cos_endpoint,
+                                                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                                                secret_access_key=self.cos_credentials['cos_hmac_keys'][
+                                                    'secret_access_key']),
+                        location=S3Location(bucket="not_existing",
+                                            path=self.data_cos_path)
+                    )],
                 training_results_reference=self.results_connection,
                 background_mode=False)
 
-        with self.assertRaises(NotExistingCOSResource, msg="Training should raise error when non existing COS file given"):
+        with self.assertRaises(NotExistingCOSResource,
+                               msg="Training should raise error when non existing COS file given"):
             self.remote_auto_pipelines.fit(
                 training_data_reference=[
                     DataConnection(
@@ -266,8 +270,12 @@ class TestAutoAIRemote(unittest.TestCase):
             self.remote_auto_pipelines.predict(X=self.X_values[:5])
 
     def test_10_summary_listing_all_pipelines_from_wml(self):
-        pipelines_details = self.remote_auto_pipelines.summary()
-        print(pipelines_details.to_string())
+        pipelines_summary = self.remote_auto_pipelines.summary()
+        print(pipelines_summary.to_string())
+        # best_pipeline = self.remote_auto_pipelines.summary()._series['Enhancements'].keys()[0]
+
+        TestAutoAIRemote.winning_pipelines_summary = pipelines_summary[pipelines_summary['Winner']]
+        TestAutoAIRemote.discarded_pipelines_summary = pipelines_summary[pipelines_summary['Winner'] == False]
 
     def test_11__get_data_connections__return_a_list_with_data_connections_with_optimizer_params(self):
         data_connections = self.remote_auto_pipelines.get_data_connections()
@@ -299,10 +307,10 @@ class TestAutoAIRemote(unittest.TestCase):
             with self.assertRaises(ForecastingUnsupportedOperation, msg="Operation should be unsupported"):
                 self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
 
-    #################################
-    #      DEPLOYMENT SECTION       #
-    #################################
-
+    # #################################
+    # #      DEPLOYMENT SECTION       #
+    # #################################
+    #
     def test_21_deployment_setup_and_preparation(self):
         TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
                                               source_project_id=self.project_id,
@@ -316,12 +324,30 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertEqual(self.service.id, None, msg="Deployment ID initialized incorrectly")
         self.assertEqual(self.service.name, None, msg="Deployment name initialized incorrectly")
 
-    def test_22__deploy__deploy_best_computed_pipeline_from_autoai_on_wml(self):
-        best_pipeline = self.remote_auto_pipelines.summary()._series['Enhancements'].keys()[0]
-        print('Deploying', best_pipeline)
+    def test_22a_deploy__deploy_best_computed_pipeline_from_autoai_on_wml(self):
+        with self.assertRaises(DiscardedModel,
+                               msg="Discarded pipeline was deployed, but it should be blocked"):
+            pipeline_name = self.discarded_pipelines_summary.reset_index()['Pipeline Name'][0]
+
+            self.service.create(
+                experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
+                model=pipeline_name,
+                deployment_name=self.DEPLOYMENT_NAME)
+
+    def test_22b_deploy__deploy_best_computed_pipeline_from_autoai_on_wml(self):
+        with self.assertRaises(WrongModelName,
+                               msg="Incorrect pipeline name was not cached."):
+            self.service.create(
+                experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
+                model="Pipeline_150",
+                deployment_name=self.DEPLOYMENT_NAME)
+
+    def test_22c_deploy__deploy_best_computed_pipeline_from_autoai_on_wml(self):
+        pipeline_name = self.winning_pipelines_summary.reset_index()['Pipeline Name'][0]
+        print('Deploying', pipeline_name)
         self.service.create(
             experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
-            model=best_pipeline,
+            model=pipeline_name,
             deployment_name=self.DEPLOYMENT_NAME)
 
         self.assertIsNotNone(self.service.id, msg="Online Deployment creation - missing id")
@@ -330,7 +356,7 @@ class TestAutoAIRemote(unittest.TestCase):
                              msg="Online Deployment creation - mscoring url  missing")
 
     def test_23_score_deployed_model(self):
-        predictions = self.service.score(payload=pd.DataFrame({'Cases' : []}))
+        predictions = self.service.score(payload=pd.DataFrame({'Cases': []}))
         print(predictions)
         self.assertIsNotNone(predictions)
 
@@ -370,16 +396,50 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertEqual(self.service_batch.id, None, msg="Deployment ID initialized incorrectly")
         self.assertEqual(self.service_batch.name, None, msg="Deployment name initialized incorrectly")
 
-    def test_32__deploy__batch_deploy_best_computed_pipeline_from_autoai_on_wml(self):
+
+    def test_32a_deploy__batch_deploy_best_computed_pipeline_from_autoai_on_wml(self):
+        with self.assertRaises(DiscardedModel,
+                               msg="Discarded pipeline was deployed, but it should be blocked"):
+            pipeline_name = self.discarded_pipelines_summary.reset_index()['Pipeline Name'][0]
+
+            self.service_batch.create(
+                experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
+                model=pipeline_name,
+                deployment_name=self.DEPLOYMENT_NAME + ' BATCH')
+
+            self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - missing id")
+            self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - name not set")
+            self.assertIsNotNone(self.service_batch.asset_id,
+                                 msg="Batch Deployment creation - model (asset) id missing, incorrect model storing")
+
+    def test_32b_deploy__batch_deploy_best_computed_pipeline_from_autoai_on_wml(self):
+        with self.assertRaises(WrongModelName,
+                               msg="Incorrect pipeline name was not cached."):
+
+            self.service_batch.create(
+                experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
+                model="Pipeline_150",
+                deployment_name=self.DEPLOYMENT_NAME + ' BATCH')
+
+            self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - missing id")
+            self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - name not set")
+            self.assertIsNotNone(self.service_batch.asset_id,
+                                 msg="Batch Deployment creation - model (asset) id missing, incorrect model storing")
+
+    def test_32c_deploy__batch_deploy_best_computed_pipeline_from_autoai_on_wml(self):
+        pipeline_name = self.winning_pipelines_summary.reset_index()['Pipeline Name'][-1]
+        print('Deploying', pipeline_name)
+
         self.service_batch.create(
             experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
-            model="Pipeline_2",
+            model=pipeline_name,
             deployment_name=self.DEPLOYMENT_NAME + ' BATCH')
 
         self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - missing id")
         self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - name not set")
         self.assertIsNotNone(self.service_batch.asset_id,
-                          msg="Batch Deployment creation - model (asset) id missing, incorrect model storing")
+                             msg="Batch Deployment creation - model (asset) id missing, incorrect model storing")
+
 
     def test_33_score_batch_deployed_model(self):
         scoring_params = self.service_batch.run_job(
@@ -410,5 +470,7 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertEqual(self.service_batch.name, None, msg="Deployment name deleted incorrectly")
         self.assertEqual(self.service_batch.scoring_url, None,
                          msg="Deployment scoring_url deleted incorrectly")
+
+
 if __name__ == '__main__':
     unittest.main()
