@@ -65,6 +65,8 @@ class TestAutoAIRemote(unittest.TestCase):
     results_cos_path = 'results_wml_autoai'
 
     pipeline: 'Pipeline' = None
+    winning_pipelines_summary = None
+    discarded_pipelines_summary = None
     lale_pipeline = None
     deployed_pipeline = None
     hyperopt_pipelines = None
@@ -262,8 +264,12 @@ class TestAutoAIRemote(unittest.TestCase):
             self.remote_auto_pipelines.predict(X=self.X_values[:5])
 
     def test_10_summary_listing_all_pipelines_from_wml(self):
-        pipelines_details = self.remote_auto_pipelines.summary()
-        print(pipelines_details.to_string())
+        pipelines_summary = self.remote_auto_pipelines.summary()
+        print(pipelines_summary.to_string())
+        # best_pipeline = self.remote_auto_pipelines.summary()._series['Enhancements'].keys()[0]
+
+        TestAutoAIRemote.winning_pipelines_summary = pipelines_summary[pipelines_summary['Winner']]
+        TestAutoAIRemote.discarded_pipelines_summary = pipelines_summary[pipelines_summary['Winner'] == False]
 
     def test_11__get_data_connections__return_a_list_with_data_connections_with_optimizer_params(self):
         data_connections = self.remote_auto_pipelines.get_data_connections()
@@ -313,11 +319,11 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertEqual(self.service.name, None, msg="Deployment name initialized incorrectly")
 
     def test_22__deploy__deploy_best_computed_pipeline_from_autoai_on_wml(self):
-        best_pipeline = self.remote_auto_pipelines.summary()._series['Enhancements'].keys()[0]
-        print('Deploying', best_pipeline)
+        pipeline_name = self.winning_pipelines_summary.reset_index()['Pipeline Name'][0]
+        print('Deploying', pipeline_name)
         self.service.create(
             experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
-            model=best_pipeline,
+            model=pipeline_name,
             deployment_name=self.DEPLOYMENT_NAME)
 
         self.assertIsNotNone(self.service.id, msg="Online Deployment creation - missing id")
@@ -362,15 +368,19 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertEqual(self.service_batch.name, None, msg="Deployment name initialized incorrectly")
 
     def test_32__deploy__batch_deploy_best_computed_pipeline_from_autoai_on_wml(self):
+        pipeline_name = self.winning_pipelines_summary.reset_index()['Pipeline Name'][0]
+        print('Deploying', pipeline_name)
+
         self.service_batch.create(
             experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
-            model="Pipeline_2",
+            model=pipeline_name,
             deployment_name=self.DEPLOYMENT_NAME + ' BATCH')
 
         self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - missing id")
         self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - name not set")
         self.assertIsNotNone(self.service_batch.asset_id,
-                          msg="Batch Deployment creation - model (asset) id missing, incorrect model storing")
+                             msg="Batch Deployment creation - model (asset) id missing, incorrect model storing")
+
 
     def test_33_score_batch_deployed_model(self):
         scoring_params = self.service_batch.run_job(
