@@ -141,6 +141,7 @@ def get_space_id(wml_client, space_name, cos_resource_instance_id=None):
             metadata = {
                 wml_client.spaces.ConfigurationMetaNames.NAME: space_name,
                 wml_client.spaces.ConfigurationMetaNames.STORAGE: {
+                    'type': 'bmcos_object_storage',
                     "resource_crn": cos_resource_instance_id},
                 wml_client.spaces.ConfigurationMetaNames.COMPUTE: {
                     "name": get_wml_credentials()['name'],
@@ -547,7 +548,7 @@ def create_connection_to_cos(wml_client, cos_credentials, cos_endpoint, bucket_n
 
     connection_details = wml_client.connections.create({
         'datasource_type': wml_client.connections.get_datasource_type_uid_by_name('bluemixcloudobjectstorage'),
-        'name': 'Connection to COS for tests',
+        'name': f'Connection to COS for tests {datetime.datetime.utcnow().isoformat()}',
         'properties': {
             'bucket': bucket_name,
             'access_key': cos_credentials['cos_hmac_keys']['access_key_id'],
