@@ -63,7 +63,9 @@ __all__ = [
     'ParamOutOfRange',
     'CannotConnectToWebsocket',
     'TestDataNotPresent',
-    'NoAutomatedHoldoutSplit'
+    'NoAutomatedHoldoutSplit',
+    'DiscardedModel',
+    'WrongModelName'
 ]
 
 from ibm_watson_machine_learning.utils import WMLClientError
@@ -318,9 +320,11 @@ class InvalidDataAsset(WMLClientError, ValueError):
         WMLClientError.__init__(self, "Data Asset without 'connection' is not supported for result store action.",
                                 reason)
 
+
 class ParamOutOfRange(WMLClientError, ValueError):
     def __init__(self, param_name, value, min, max):
-        WMLClientError.__init__(self, f"Value of parameter `{param_name}`, {value}, is out of expected range - between {min} and {max}.")
+        WMLClientError.__init__(self,
+                                f"Value of parameter `{param_name}`, {value}, is out of expected range - between {min} and {max}.")
 
 
 class CannotConnectToWebsocket(WMLClientError, ValueError):
@@ -340,3 +344,19 @@ class NoAutomatedHoldoutSplit(WMLClientError, ValueError):
                                       "To recreate holdout split, please use test data connection."
                                       "You can call optimizer.get_test_data_connections().",
                                 reason)
+
+
+class DiscardedModel(WMLClientError, ValueError):
+    def __init__(self, model_name):
+        WMLClientError.__init__(self,
+                                "You are trying to store a discarded TS model pipeline. Please use not discarded one."
+                                "Look at the pipelines 'summary' method and choose the 'Winner' one.",
+                                reason=f"Pipeline: '{model_name}' is discarded!")
+
+
+class WrongModelName(WMLClientError, ValueError):
+    def __init__(self, model_name):
+        WMLClientError.__init__(self,
+                                "This model name does not exist. Please provide correct one."
+                                "Look at the pipelines 'summary' method and choose the 'Winner' one.",
+                                reason=f"Pipeline: '{model_name}' does not exist!")
