@@ -45,7 +45,8 @@ __all__ = [
     'validate_additional_params_for_optimizer',
     'is_list_composed_from_enum',
     'validate_optimizer_enum_values',
-    'all_logging_disabled'
+    'all_logging_disabled',
+    'check_if_ts_pipeline_is_winner'
 ]
 
 import io
@@ -74,7 +75,8 @@ from .enums import (RegressionAlgorithms, RegressionAlgorithmsCP4D, Classificati
                     Metrics, TShirtSize, PredictionType, DataConnectionTypes)
 from .errors import (MissingPipeline, DataFormatNotSupported, LibraryNotCompatible,
                      CannotInstallLibrary, CannotDownloadTrainingDetails, CannotDownloadWMLPipelineDetails,
-                     VisualizationFailed, AdditionalParameterIsUnexpected, InvalidSequenceValue, NoAvailableMetrics)
+                     VisualizationFailed, AdditionalParameterIsUnexpected, InvalidSequenceValue, NoAvailableMetrics,
+                     DiscardedModel, WrongModelName)
 
 if TYPE_CHECKING:
     from io import BytesIO, BufferedIOBase
@@ -1830,3 +1832,18 @@ def all_logging_disabled(highest_level=logging.CRITICAL):
         yield
     finally:
         logging.disable(previous_level)
+
+
+def check_if_ts_pipeline_is_winner(details: dict, model_name: str) -> None:
+    """Check if ts pipeline is the winner one. It should be used before model store in the repo."""
+    is_ts_metrics = 'ts_metrics' in details['entity']['status'].get('metrics', [{}])[0]
+    if is_ts_metrics:
+        summary = create_summary(details=details, scoring=None)
+        summary.reset_index(inplace=True)
+        vals = summary[summary['Pipeline Name'] == model_name]['Winner'].values
+        if len(vals) == 0:
+            raise WrongModelName(model_name)
+
+        else:
+            if not vals[0]:
+                raise DiscardedModel(model_name)
