@@ -22,6 +22,8 @@ import shutil
 import tarfile
 import logging
 
+import requests
+
 
 INSTANCE_DETAILS_TYPE = u'instance_details_type'
 PIPELINE_DETAILS_TYPE = u'pipeline_details_type'
@@ -538,3 +540,57 @@ def is_of_python_basic_type(el):
         return is_of_python_basic_type(list(el.values()))
     else:
         return False
+
+
+class NextResourceGenerator:
+    """
+    Generator class to produce next list of resources from REST API.
+
+    Parameters
+    ----------
+    wml_client: APIClient, required
+        WML Client Instance
+
+    href: str, required
+        Href to the resource
+    """
+
+    def __init__(self, wml_client: 'APIClient', url: str, href: str, params: dict = None, _all=False) -> None:
+        self.wml_client = wml_client
+        self.url = url
+        self.next_href = href
+        self.params = params
+        self.all = _all
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        if self.next_href is not None:
+            response = requests.get(
+                url=f"{self.url}/{self.next_href}",
+                headers=self.wml_client._get_headers(),
+                params=self.params if self.params is not None else self.wml_client.params(),
+                verify=not self.wml_client.ICP
+            )
+            details_json = self.wml_client.training._handle_response(200, "Get next details", response)
+
+            if self.all:
+                self.next_href = details_json.get('next', {'href': None})['href']
+
+            else:
+                self.next_href = None
+
+            if 'resources' in details_json:
+                resources = details_json['resources']
+
+            elif 'metadata' in details_json:
+                resources = [details_json]
+
+            else:
+                resources = details_json.get('results', [])
+
+            return resources
+
+        else:
+            raise StopIteration
