@@ -185,7 +185,7 @@ class SWSReceiver(FLReceiver):
         apikey_header = None
         while not self.stopped:
             try:
-                logger.debug("SWSReceiver.establish_websocket_connection ATTEMPT async websockets.connect")
+                logger.info("SWSReceiver.establish_websocket_connection ATTEMPT async websockets.connect")
                 async with websockets.connect(uri, close_timeout=1000, max_size=2 ** 29, read_limit=2 ** 29, write_limit=2**29, loop=loop, extra_headers=headers) as websocket:
                     logger.info("Received Heartbeat from Aggregator")
                     apikey_header = websocket.response_headers.get("apikey", None)
@@ -339,6 +339,12 @@ class SWSReceiver(FLReceiver):
             self.stopping = True
             return
 
+        # check if error
+        if (recv_msg.message_type == MessageType.ERROR_AUTH.value):
+            logger.info("Authorization Error. Please verify ip address, training ID, RTS, project permission and token")
+            self.stopped = True
+            return
+
         # if recv_msg.sender_info is not None and recv_msg.sender_info == self.party:
         #     logger.info("Received Message is reply to previously sent message")
         #     return
