@@ -21,6 +21,7 @@ from ibmfl.model.fl_model import FLModel
 from ibmfl.model.model_update import ModelUpdate
 from ibmfl.exceptions import FLException, LocalTrainingException, ModelException
 from tensorflow.keras import backend as K
+from sklearn.model_selection import train_test_split
 
 logger = logging.getLogger(__name__)
 
@@ -70,6 +71,7 @@ class TensorFlowFLModel(FLModel):
         # Default values for local training
         self.batch_size = 128
         self.epochs = 1
+        self.validation_split = 0
         self.steps_per_epoch = None
         self.is_classification = True if not (model_spec and model_spec.get(
             'is_classification')) else model_spec.get('is_classification')
@@ -92,6 +94,7 @@ class TensorFlowFLModel(FLModel):
         """
         fit_args = self.get_fit_args(fit_params, **kwargs)
         if validation_data is not None:
+            fit_args.pop('validation_split', None)
             fit_args['validation_data'] = validation_data
 
         logger.info('Training hps for this round => '
@@ -112,6 +115,7 @@ class TensorFlowFLModel(FLModel):
                     train_data.set_batch_size(fit_args.get('batch_size'))
 
                 fit_args.pop('batch_size', None)
+                fit_args.pop('validation_split', None)
                 self.model.fit(train_data, **fit_args)
 
         except Exception as e:
@@ -608,7 +612,6 @@ class TensorFlowFLModel(FLModel):
 
         fit_args = {}
         local_params = kwargs.get('local_params', {}) or {} if global_params else {}
-
         hyperparams = global_params.get('hyperparams', {}) or {} if global_params else {}
         local_hp = hyperparams.get('local', {}) or {}
         training_hp = local_hp.get('training', {}) or {}
@@ -620,6 +623,20 @@ class TensorFlowFLModel(FLModel):
         logger.info("Learning rate of optimizer is set as {}".format(
             self.model.optimizer.learning_rate))
 
+        validation_split = training_hp.get('validation_split', self.validation_split)
+        try:
+            if float(validation_split) != 0:
+                fit_args['validation_split'] = float(validation_split)
+        except (TypeError, ValueError):
+            raise ValueError('Validation split cannot be a NoneType')
+        if 'validation_split' in local_params:
+            validation_split = local_params.get('validation_split')
+            try:
+                if float(validation_split) != 0:
+                    fit_args['validation_split'] = float(validation_split)
+            except (TypeError, ValueError):
+                raise ValueError('Validation split cannot be a NoneType')
+
         fit_args['batch_size'] = training_hp.get('batch_size', self.batch_size)
         if 'batch_size' in local_params:
             fit_args['batch_size'] = local_params.get('batch_size')
