@@ -235,7 +235,7 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
 
         return party_id, self.sketchers, self.X_ptiles_train
 
-    def init_null_preds(self):
+    def init_null_preds(self, baseline):
         """
         Initialize null predictions from baseline models. These values are used
         to construct the initial tree structure of the model. Note that
@@ -248,8 +248,7 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
         """
         # Generate Baseline Predictions
         logger.info('Generating Initial Predictions from Null Model')
-        self.baseline = self.loss_.get_baseline_prediction(
-            self.y_train, self.sample_weight, self.n_trees)
+        self.baseline = baseline
         self.raw_predictions = np.zeros(shape=(self.n_trees, self.n_samples),
                                         dtype=self.baseline.dtype) + self.baseline
 
@@ -396,6 +395,20 @@ class XGBRegressorLocalTrainingHandler(XGBoostBaseLocalTrainingHandler):
         """
         return _LOSSES[self.loss](sample_weight=sample_weight)
 
+    def get_avg_stats(self):
+        """
+        Helper process to compute necessary statistics for computing the global
+        average. Wrapper function calls respective function to derive statistics
+        based on the defined loss function.
+
+        :return: Returns y_hat * n and n.
+        :rtype: (`np.array`, `np.array`)
+        """
+        logger.info('Compute Local Party Average Statistics')
+
+        return (np.array(np.average(self.y_train, weights=self.sample_weight)), \
+                np.array([len(self.y_train)]))
+
 
 class XGBClassifierLocalTrainingHandler(XGBoostBaseLocalTrainingHandler):
     _VALID_LOSSES = ('binary_crossentropy', 'categorical_crossentropy', 'auto')
@@ -457,3 +470,26 @@ class XGBClassifierLocalTrainingHandler(XGBoostBaseLocalTrainingHandler):
                 _LOSSES['categorical_crossentropy'](sample_weight=sample_weight)
         else:
             return _LOSSES[self.loss](sample_weight=sample_weight)
+
+    def get_avg_stats(self):
+        """
+        Helper process to compute necessary statistics for computing the global
+        average. Wrapper function calls respective function to derive statistics
+        based on the defined loss function.
+
+        :return: Returns y_hat * n and n.
+        :rtype: (`np.array`, `np.array`)
+        """
+        logger.info('Compute Local Party Average Statistics')
+
+        # Compute Average Depending on the Value
+        if (self.n_trees == 1) or self.loss == 'binary_crossentropy':
+            return (np.array([np.average(self.y_train, weights=self.sample_weight)]), \
+                    np.array([len(self.y_train)]))
+        elif self.loss == 'categorical_crossentropy':
+            average, counts = [], []
+            for k in range(self.num_classes):
+                average.append(np.average(self.y_train == k,\
+                               weights=self.sample_weight))
+                counts.append(len(self.y_train == k))
+            return (np.array(average), np.array(counts))
