@@ -192,6 +192,7 @@ def get_cls_by_config(config_dict):
         config_dict.get('local_training'))
     cls_config['privacy'] = config_dict.get('privacy')
     cls_config['metrics'] = get_mh_from_config(config_dict.get('metrics'))
+    cls_config['evidencia'] = get_evidencia_from_config(config_dict.get('evidencia'))
     cls_config['key_generators'] = config_dict.get('key_generators')
     cls_config['access_white_lst'] = config_dict.get('access_white_lst')
 
@@ -341,6 +342,34 @@ def get_ph_from_config(config):
     return ph_config
 
 
+def get_evidencia_from_config(config):
+    """ Evidencia recorder class information from params provided in config file
+    :param config: dictionary of configuration
+    :type config: `dict`
+    :return: dictionary of class references
+    :rtype: `dict`
+    """
+    # TODO: validation needs to be added
+    evidencia_config = {}
+    if config:
+        try:
+            evidencia_config['cls_ref'] = get_class_by_name(
+                config['path'], config['name'])
+            if 'info' in config:
+                evidencia_config['info'] = config['info']
+
+        except Exception as ex:
+            logger.exception(ex)
+
+            raise InvalidConfigurationException(
+                'Error occurred while loading evidencia recorder config.')
+
+    else:
+        logger.info('No evidencia recordeer config provided for this setup.')
+
+    return evidencia_config
+
+
 def get_lt_from_config(config):
     """ Load local training class information from params provided in config file
     :param config: dictionary of configuration
